==> qore-0.9.4.tar.bz2: qore-0.9.4/docs/modules/RestSchemaValidator/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore RestSchemaValidator Module Reference", "index.html", [
    [ "RestSchemaValidator module", "index.html", [
      [ "RestSchemaValidator Module Introduction", "index.html#restschemavalidatorintro", null ],
      [ "RestSchemaValidator Module Release Notes", "index.html#restschemavalidator_relnotes", [
        [ "RestSchemaValidator v2.0", "index.html#restschemavalidator_2_0", null ],
        [ "RestSchemaValidator v1.1.2", "index.html#restschemavalidator_1_1_2", null ],
        [ "RestSchemaValidator v1.1.1", "index.html#restschemavalidator_1_1_1", null ],
        [ "RestSchemaValidator v1.1", "index.html#restschemavalidator_1_1", null ],
        [ "RestSchemaValidator v1.0.2", "index.html#restschemavalidator_1_0_2", null ],
        [ "RestSchemaValidator v1.0.1", "index.html#restschemavalidator_1_0_1", null ],
        [ "RestSchemaValidator v1.0", "index.html#restschemavalidator_1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.4.1.tar.bz2: qore-0.9.4.1/docs/modules/RestSchemaValidator/html/navtreedata.js <==
/*
@licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2019 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of version 2 of the GNU General Public License as published by
the Free Software Foundation

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore RestSchemaValidator Module Reference", "index.html", [
    [ "RestSchemaValidator module", "index.html", [
      [ "RestSchemaValidator Module Introduction", "index.html#restschemavalidatorintro", null ],
      [ "RestSchemaValidator Module Release Notes", "index.html#restschemavalidator_relnotes", [
        [ "RestSchemaValidator v2.0", "index.html#restschemavalidator_2_0", null ],
        [ "RestSchemaValidator v1.1.2", "index.html#restschemavalidator_1_1_2", null ],
        [ "RestSchemaValidator v1.1.1", "index.html#restschemavalidator_1_1_1", null ],
        [ "RestSchemaValidator v1.1", "index.html#restschemavalidator_1_1", null ],
        [ "RestSchemaValidator v1.0.2", "index.html#restschemavalidator_1_0_2", null ],
        [ "RestSchemaValidator v1.0.1", "index.html#restschemavalidator_1_0_1", null ],
        [ "RestSchemaValidator v1.0", "index.html#restschemavalidator_1_0", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
